@@ -27,7 +27,7 @@ class RedisHelper:
             return aioredis.Redis(connection_pool=self.pool, decode_responses=True)
 
     async def set(self, name, value, ex=None, px=None, nx: bool = False, xx: bool = False, keepttl: bool = False):
-        await self.get_connection().set(name, value, ex, px, nx, xx, keepttl)
+        return await self.get_connection().set(name, value, ex, px, nx, xx, keepttl)
 
     async def get(self, name):
         return await self.get_connection().get(name)
@@ -40,20 +40,22 @@ class RedisHelper:
 
     async def delete(self, names):
         if isinstance(names, list) or isinstance(names, tuple):
-            await self.get_connection().delete(*names)
+            return await self.get_connection().delete(*names)
         else:
-            await self.get_connection().delete(names)
+            return await self.get_connection().delete(names)
 
     async def rpush(self, name, values: list, time=None):
-        await self.get_connection().rpush(name, *values)
+        res = await self.get_connection().rpush(name, *values)
         if time:
             await self.get_connection().expire(name, time)
+        return res
 
     async def hset(self, name, key=None, value=None, mapping=None, time=None):
         con = self.get_connection()
-        await con.hset(name, key=key, value=value, mapping=mapping)
+        res = await con.hset(name, key=key, value=value, mapping=mapping)
         if time:
             await con.expire(name, time)
+        return res
 
     async def hgetall(self, name):
         return await self.get_connection().hgetall(name)
@@ -81,9 +83,10 @@ class RedisHelper:
 
     async def hmset(self, name, mapping, time=None):
         con = self.get_connection()
-        await con.hmset(name, mapping)
+        res = await con.hmset(name, mapping)
         if time:
             await con.expire(name, time)
+        return res
 
     async def hmget(self, name, keys, *args):
         return await self.get_connection().hmget(name, keys, *args)
@@ -96,9 +99,10 @@ class RedisHelper:
 
     async def sadd(self, name, values: list, time=None):
         con = self.get_connection()
-        await con.sadd(name, *values)
+        res = await con.sadd(name, *values)
         if time:
             await con.expire(name, time)
+        return res
 
     async def scard(self, name):
         return await self.get_connection().scard(name)
@@ -116,7 +120,7 @@ class RedisHelper:
         return await self.get_connection().srem(name, *values)
 
     def sync_set(self, name, value, ex=None, px=None, nx: bool = False, xx: bool = False, keepttl: bool = False):
-        self.get_connection(sync=True).set(name, value, ex, px, nx, xx, keepttl)
+        return self.get_connection(sync=True).set(name, value, ex, px, nx, xx, keepttl)
 
     def sync_get(self, name):
         return self.get_connection(sync=True).get(name)
@@ -129,21 +133,23 @@ class RedisHelper:
 
     def sync_delete(self, names):
         if isinstance(names, list) or isinstance(names, tuple):
-            self.get_connection(sync=True).delete(*names)
+            return self.get_connection(sync=True).delete(*names)
         else:
-            self.get_connection(sync=True).delete(names)
+            return self.get_connection(sync=True).delete(names)
 
     def sync_rpush(self, name, values: list, time=None):
         con = self.get_connection(sync=True)
-        con.rpush(name, *values)
+        res = con.rpush(name, *values)
         if time:
             con.expire(name, time)
+        return res
 
     def sync_hset(self, name, key=None, value=None, mapping=None, time=None):
         con = self.get_connection(sync=True)
-        con.hset(name, key=key, value=value, mapping=mapping)
+        res = con.hset(name, key=key, value=value, mapping=mapping)
         if time:
             con.expire(name, time)
+        return res
 
     def sync_hgetall(self, name):
         return self.get_connection(sync=True).hgetall(name)
@@ -171,9 +177,10 @@ class RedisHelper:
 
     def sync_hmset(self, name, mapping, time=None):
         con = self.get_connection(sync=True)
-        con.hmset(name, mapping)
+        res = con.hmset(name, mapping)
         if time:
             con.expire(name, time)
+        return res
 
     def sync_hmget(self, name, keys, *args):
         return self.get_connection(sync=True).hmget(name, keys, *args)
@@ -186,9 +193,10 @@ class RedisHelper:
 
     def sync_sadd(self, name, values: list, time=None):
         con = self.get_connection(sync=True)
-        con.sadd(name, *values)
+        res = con.sadd(name, *values)
         if time:
             con.expire(name, time)
+        return res
 
     def sync_scard(self, name):
         return self.get_connection(sync=True).scard(name)
