@@ -31,6 +31,11 @@ def parser_swagger(func, desc):
             "in": "header",
             "required": False,
             "type": "string"
+        },{
+            "name": "User",
+            "in": "header",
+            "required": False,
+            "type": "string"
         }]
         args = get_args(func)
         if func.__http_method__ == "get":
